# -*- coding: utf8 -*-
from __future__ import unicode_literals

import unittest

from driverng.protocol.bci import BCIProtocol
from driverng.utils import ETX, GS, RS


class BCITest(unittest.TestCase):
    def test_split(self):
        proto = BCIProtocol()
        self.assertEqual(proto.build_trames(79 * b"A")[0].count(RS), 1)
        self.assertEqual(proto.build_trames(80 * b"A")[0].count(RS), 2)

    def test_get_payload(self):
        proto = BCIProtocol()
        data = 9 * b"A"
        self.assertEqual(data, proto.get_payload(proto.build_trames(data)[0]))

    def test_checksum(self):
        proto = BCIProtocol()
        data = 10 * b"A"
        self.assertEqual(proto.checksum(data), 138)

    def test_check_trame(self):
        proto = BCIProtocol()
        message = 10 * b"A"
        trame = proto.build_trames(message)[0]

        self.assertTrue(proto.check_trame(trame))
        self.assertFalse(proto.check_trame(trame.replace(bytearray([GS]), b"")))
        self.assertFalse(proto.check_trame(b"%s%c" % (trame[:-3], ETX)))

    def test_build_trames(self):
        expected = b"\x02\x1eAAAAAAAAAA\x1dC5\x03"
        trame = BCIProtocol().build_trames(10 * b"A")[0]
        self.assertEqual(trame, expected)
